==> Mapster-1.4.3.zip: Mapster/Locale/ruRU.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "ruRU")
if not L then return end

L["(Mini) Disable Mouse"] = "(Мини) Отключить мышь"
L["(Mini) Hide Border"] = "(Мини) Скрыть края"
L["Accuracy"] = "Точность"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Ругулировка размера стрелкт игрока на карте для улучшения её видимости."
L["Alpha"] = "Прозрачность"
L["BattleMap"] = "Карта поля боя"
L["Battlegrounds"] = "Поля боя"
L["Blobs & Panels"] = "Отметки и панели"
L["Burning Crusade Instances"] = "Подземелья Burning Crusade" -- Needs review
L["Burning Crusade Raids"] = "Рейды Burning Crusade" -- Needs review
L["Cataclysm Instances"] = "Подземелья Cataclysm"
L["Cataclysm Raids"] = "Рейды Cataclysm"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Изменените масштаб карты, если не хотите видеть её развёрнутой на весь экран."
L["Classic Instances"] = "Подземелья Classic"
L["Classic Raids"] = "Рейды Classic"
L["Coordinates"] = "Координаты"
L["Cursor"] = "Курсор"
L["Debug"] = "Отладка"
L["Disable Mouse"] = "Отключить мышку"
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Отключить взаимодействие мыши с основной картой когда она минимизирована, например, измение зон."
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Отключить взаимодействие мыши с основной картой, например, измение зон."
L["Enable BattleMap"] = "Включить карту поля боя"
L["Enable Coordinates"] = "Включить координаты"
L["Enable FogClear"] = "Очищать туман"
L["Enable Group Icons"] = "Включить иконки групп"
L["Enable Instance Maps"] = "Включить карты подземелий"
L["FogClear"] = "Очистка тумана"
L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "Модуль очистки тумана войны сохраняет новые данные в SavedVariables. Сброс этих данных может понадобится в том случае, если они оказались повреждены (или просто устарели) при выходе нового патча."
L["Group Icons"] = "Иконки групп"
L["Hide Border"] = "Скрыть края"
L["Hide Completely"] = "Скрыть полностью"
L["Hide Map Button"] = "Скрыть иконку мини-карты"
L["Hide Textures"] = "Скрыть текстуры"
L["Hide the borders of the big map."] = "Скрыть края на большой карте."
L["Hide the borders of the minimized map."] = "Скрыть края на уменьшенной карте."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Скрыть окружающие текстуры вокруг карты боя, оставив только вас с подсвеченной картой."
L["Instance Maps"] = "Карты подземелий"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "С помощью Mapster'а вы сможете управлять различными параметрами карты мира. Вы можете изменить стиль карты, добавить новую функциональность с помощью плагинов, а также сконфигурировать различные профили для каждого вашего персонажа."
L["Minimized Alpha"] = "Прозрачность уменьшенной"
L["Minimized Scale"] = "Масштаб уменьшенной"
L["Note: You need to reload your UI after reseting the data!"] = "Замечание: после выполнения этой операции необходимо перезагрузить ваш интерфейс!"
L["Only WorldMap Blobs"] = "Только отметки на карте мира"
L["Overlay Color"] = "Цвет подсветки"
L["POI Scale"] = "Масштаб POI"
L["Player"] = "Игрок"
L["PlayerArrow Scale"] = "Масштаб стрелки игрока"
L["Quest Objectives"] = "Цели задания"
L["Reset FogClear Data"] = "Сбросить данные очистки тумана"
L["Scale"] = "Масштаб"
L["Scale of the POI Icons on the Map."] = "Масштаб иконок POI на карте."
L["Scale of the big map."] = "Масштаб большой карты."
L["Scale of the minimized map."] = "Масштаб уменьшенной карты."
L["Size on the Battle Map"] = "Размер на карте Сражения"
L["Size on the World Map"] = "Размер на карте Мира"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "Модуль карт поля боя позволяет изменять стиль в мини-карты поля боя, убирая ненужные текстуры или PvP задачи."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "Модуль координат добавляет строку с отображением вашего текущего местоположения, а также с положением курсора на карте."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "Модуль очистки тумана войны делает скрытые (неисследованные) зоны видимыми, подсвечивая их особым цветом."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "Модуль группы иконок позволяющий вам изменять размер иконок рейда и группы на карте мира."
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "Модуль карт подземелий  позволяет просматривать подземелья и поля боя, представленные в игре."
L["The transparency of the big map."] = "Прозрачность большой карты."
L["The transparency of the minimized map."] = "Прозрачность уменьшенной карты."
L["Turn on debugging for the FogClear Module."] = "Включить режим отладки для модуля очистки тумана войны."
L["Wrath Instances"] = "Подземелья WotLK"
L["Wrath Raids"] = "Рейды WotLK"
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Вы можете изменить прозрачность карты, что позволит вам видеть окружающую обстановку в то время, как карта будет открыта."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Вы можете управлять точностью координат, например, если вам нужные очень точные координаты - вы можете установить это значение как 2."

==> Mapster-1.5.6.1.zip: Mapster/Locale/ruRU.lua <==
-- Mapster Locale
-- Please use the Localization App on WoWAce to Update this
-- http://www.wowace.com/projects/mapster/localization/ ;¶

local L = LibStub("AceLocale-3.0"):NewLocale("Mapster", "ruRU")
if not L then return end

L["Accuracy"] = "Точность"
L["Adjust the size of the Player Arrow on the Map for better visibility."] = "Ругулировка размера стрелкт игрока на карте для улучшения её видимости."
L["Alpha"] = "Прозрачность"
L["Battlegrounds"] = "Поля боя"
L["BattleMap"] = "Карта поля боя"
L["Blobs & Panels"] = "Отметки и панели"
L["Burning Crusade Instances"] = "Подземелья Burning Crusade" -- Needs review
L["Burning Crusade Raids"] = "Рейды Burning Crusade" -- Needs review
L["Cataclysm Instances"] = "Подземелья Cataclysm"
L["Cataclysm Raids"] = "Рейды Cataclysm"
L["Change the scale of the world map if you do not want the whole screen filled while the map is open."] = "Изменените масштаб карты, если не хотите видеть её развёрнутой на весь экран."
L["Classic Instances"] = "Подземелья Classic"
L["Classic Raids"] = "Рейды Classic"
L["Coordinates"] = "Координаты"
L["Cursor"] = "Курсор"
L["Debug"] = "Отладка"
L["Disable Mouse"] = "Отключить мышку"
L["Disable the mouse interactivity of the main map, eg. to change zones."] = "Отключить взаимодействие мыши с основной картой, например, измение зон."
L["Disable the mouse interactivity of the main map when in minimized mode, eg. to change zones."] = "Отключить взаимодействие мыши с основной картой когда она минимизирована, например, измение зон."
L["EJ Icon Scale"] = "Размер иконки журнала встреч" -- Needs review
L["Enable BattleMap"] = "Включить карту поля боя"
L["Enable Coordinates"] = "Включить координаты"
L["Enable FogClear"] = "Очищать туман"
L["Enable Group Icons"] = "Включить иконки групп"
L["Enable Instance Maps"] = "Включить карты подземелий"
L["FogClear"] = "Очистка тумана"
L["FogClear collects new Data in your own SavedVariables, but that data might get corrupted (or simply old) with a new patch. Reset the data if you see corruption in the world map."] = "Модуль очистки тумана войны сохраняет новые данные в SavedVariables. Сброс этих данных может понадобится в том случае, если они оказались повреждены (или просто устарели) при выходе нового патча."
L["Group Icons"] = "Иконки групп"
L["Hide Border"] = "Скрыть края"
L["Hide Completely"] = "Скрыть полностью"
L["Hide Map Button"] = "Скрыть иконку мини-карты"
L["Hide Quest Panels"] = "Скрыть панель квестов" -- Needs review
L["Hide Textures"] = "Скрыть текстуры"
L["Hide the borders of the big map."] = "Скрыть края на большой карте."
L["Hide the borders of the minimized map."] = "Скрыть края на уменьшенной карте."
L["Hide the surrounding textures around the BattleMap, only leaving you with the pure map overlays."] = "Скрыть окружающие текстуры вокруг карты боя, оставив только вас с подсвеченной картой."
L["Instance Maps"] = "Карты подземелий"
L["Mapster allows you to control various aspects of your World Map. You can change the style of the map, control the plugins that extend the map with new functionality, and configure different profiles for every of your characters."] = "С помощью Mapster'а вы сможете управлять различными параметрами карты мира. Вы можете изменить стиль карты, добавить новую функциональность с помощью плагинов, а также сконфигурировать различные профили для каждого вашего персонажа."
L["(Mini) Disable Mouse"] = "(Мини) Отключить мышь"
L["(Mini) Hide Border"] = "(Мини) Скрыть края"
L["Minimized Alpha"] = "Прозрачность уменьшенной"
L["Minimized Scale"] = "Масштаб уменьшенной"
L["Note: You need to reload your UI after reseting the data!"] = "Замечание: после выполнения этой операции необходимо перезагрузить ваш интерфейс!"
L["Only WorldMap Blobs"] = "Только отметки на карте мира"
L["Overlay Color"] = "Цвет подсветки"
L["Pandaria Instances"] = "Подземелья Mists of Pandaria" -- Needs review
L["Pandaria Raids"] = "Рейды Mists of Pandaria" -- Needs review
L["Player"] = "Игрок"
L["PlayerArrow Scale"] = "Масштаб стрелки игрока"
L["POI Scale"] = "Масштаб POI"
L["Reset FogClear Data"] = "Сбросить данные очистки тумана"
L["Scale"] = "Масштаб"
L["Scale of the big map."] = "Масштаб большой карты."
L["Scale of the Encounter Journal Icons on the Map."] = "Увеличить иконки журнала встреч на карте" -- Needs review
L["Scale of the minimized map."] = "Масштаб уменьшенной карты."
L["Scale of the POI Icons on the Map."] = "Масштаб иконок POI на карте."
L["Size on the Battle Map"] = "Размер на карте Сражения"
L["Size on the World Map"] = "Размер на карте Мира"
L["The BattleMap module allows you to change the style of the BattlefieldMinimap, removing unnecessary textures or PvP Objectives."] = "Модуль карт поля боя позволяет изменять стиль в мини-карты поля боя, убирая ненужные текстуры или PvP задачи."
L["The Coordinates module adds a display of your current location, and the coordinates of your mouse cursor to the World Map frame."] = "Модуль координат добавляет строку с отображением вашего текущего местоположения, а также с положением курсора на карте."
L["The FogClear module removes the Fog of War from the World map, thus displaying the artwork for all the undiscovered zones, optionally with a color overlay on undiscovered areas."] = "Модуль очистки тумана войны делает скрытые (неисследованные) зоны видимыми, подсвечивая их особым цветом."
L["The Group Icons module allows you to resize the raid and party icons on the world map."] = "Модуль группы иконок позволяющий вам изменять размер иконок рейда и группы на карте мира."
L["The Instance Maps module allows you to view the Instance and Battleground Maps provided by the game without being in the instance yourself."] = "Модуль карт подземелий  позволяет просматривать подземелья и поля боя, представленные в игре."
L["The transparency of the big map."] = "Прозрачность большой карты."
L["The transparency of the minimized map."] = "Прозрачность уменьшенной карты."
L["Turn on debugging for the FogClear Module."] = "Включить режим отладки для модуля очистки тумана войны."
L["Wrath Instances"] = "Подземелья WotLK"
L["Wrath Raids"] = "Рейды WotLK"
L["You can change the transparency of the world map to allow you to continue seeing the world environment while your map is open for navigation."] = "Вы можете изменить прозрачность карты, что позволит вам видеть окружающую обстановку в то время, как карта будет открыта."
L["You can control the accuracy of the coordinates, e.g. if you need very exact coordinates you can set this to 2."] = "Вы можете управлять точностью координат, например, если вам нужные очень точные координаты - вы можете установить это значение как 2."
